@@ -294,19 +294,22 @@ class OatClient:
         return ids
     
     def set_gelineq(self, coefficients: Dict[str, int], bias: int, alias: str | None = None) -> str:
+        args = {
+            "coefficients": _wrap_arg([
+                _wrap_arg({
+                    "id": _wrap_arg(self._resolve_id(k)),
+                    "coefficient": _wrap_arg(v)
+                })
+                for k, v in coefficients.items()
+            ]),
+            "bias": _wrap_arg(bias)
+        }
+        if alias is not None:
+            args["alias"] = _wrap_arg(alias)
+
         fn_data = FunctionCall(
             fn="set_gelineq",
-            args={
-                "coefficients": _wrap_arg([
-                    _wrap_arg({
-                        "id": _wrap_arg(self._resolve_id(k)),
-                        "coefficient": _wrap_arg(v)
-                    })
-                    for k, v in coefficients.items()
-                ]),
-                "bias": _wrap_arg(bias),
-                "alias": _wrap_arg(alias) if alias is not None else _wrap_arg(None)
-            },
+            args=args
         )
         fn_hash = fn_data.hash()
         fn_data.out = fn_hash
@@ -448,7 +451,9 @@ class OatClient:
                 "value": "red"
             })
         """
-        args = {}
+        args = {
+            "dag": _wrap_arg({})  # Empty DAG means use the current database state
+        }
         if filter:
             args["filter"] = _wrap_arg(filter)
         fn_data = FunctionCall(
@@ -536,10 +541,9 @@ class OatClient:
                         "fn": "get_result",
                         "args": {"id": _wrap_arg("dag")}
                     }),
-                    "objectives": _wrap_arg([
-                        {self._resolve_id(k): v for k, v in objective.items()}
-                        for objective in objectives
-                    ]),
+                    "objective": _wrap_arg(
+                        {self._resolve_id(k): v for k, v in objectives[0].items()} if objectives else {}
+                    ),
                     "assume": _wrap_arg([
                         {
                             "id": _wrap_arg(self._resolve_id(k)),
